@@ -1,4 +1,4 @@
-/* $Id: color.c,v 1.23 2003/08/05 19:31:12 jordi Exp $ */
+/* $Id: color.c,v 1.23.2.1 2004/02/18 04:33:53 astyanax Exp $ */
 /**************************************************************************
  *   color.c                                                              *
  *                                                                        *
@@ -109,7 +109,7 @@ void update_color(void)
 
 	for (e = tmpsyntax->extensions; e != NULL; e = e->next) {
 	    /* Set colorstrings if we matched the extension regex */
-	    if (!regexec(&e->val, filename, 0, NULL, 0))
+	    if (regexec(&e->val, filename, 0, NULL, 0) == 0)
 		colorstrings = tmpsyntax->color;
 
 	    if (colorstrings != NULL)
