@@ -1,4 +1,4 @@
-/* $Id: files.c,v 1.216.2.1 2003/12/27 16:35:21 uid66481 Exp $ */
+/* $Id: files.c,v 1.216.2.3 2004/06/26 00:23:40 astyanax Exp $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -165,6 +165,10 @@ int read_file(FILE *f, const char *filename, int quiet)
     int line1ins = 0;
     int input_int;
 
+#ifndef NANO_SMALL
+    jumpok = 0;
+#endif
+
     buf = charalloc(bufx);
     buf[0] = '\0';
 
@@ -334,6 +338,9 @@ int read_file(FILE *f, const char *filename, int quiet)
 
     totlines += num_lines;
 
+#ifndef NANO_SMALL
+    jumpok = 1;
+#endif
     return 1;
 }
 
@@ -1346,6 +1353,7 @@ int write_file(const char *name, int tmp, int append, int nonamechange)
 	statusbar(_("Cancelled"));
 	return -1;
     }
+
     if (!tmp)
 	titlebar(NULL);
     fileptr = fileage;
@@ -1487,6 +1495,9 @@ int write_file(const char *name, int tmp, int append, int nonamechange)
 #ifdef DEBUG
     dump_buffer(fileage);
 #endif
+#ifndef NANO_SMALL
+    jumpok = 0;
+#endif
 
     f = fdopen(fd, append == 1 ? "ab" : "wb");
     if (f == NULL) {
@@ -1698,6 +1709,9 @@ int write_file(const char *name, int tmp, int append, int nonamechange)
   cleanup_and_exit:
     free(realname);
     free(buf);
+#ifndef NANO_SMALL
+    jumpok = 1;
+#endif
     return retval;
 }
 
@@ -1707,16 +1721,17 @@ int do_writeout(const char *path, int exiting, int append)
 #ifdef NANO_EXTRA
     static int did_cred = 0;
 #endif
+    static char *writepath = NULL;
 
 #if !defined(DISABLE_BROWSER) || (!defined(DISABLE_MOUSE) && defined(NCURSES_MOUSE_VERSION))
     currshortcut = writefile_list;
 #endif
 
-    answer = mallocstrcpy(answer, path);
+    writepath = mallocstrcpy(writepath, path);
 
     if (exiting && ISSET(TEMP_OPT)) {
 	if (filename[0] != '\0') {
-	    i = write_file(answer, 0, 0, 0);
+	    i = write_file(writepath, 0, 0, 0);
 	    display_main_list();
 	    return i;
 	} else {
@@ -1757,24 +1772,24 @@ int do_writeout(const char *path, int exiting, int append)
 		    "%s%s%s", _("Write Selection to File"), formatstr, backupstr);
 	} else {
 	    if (append == 2)
-		i = statusq(1, writefile_list, answer, 0,
+		i = statusq(1, writefile_list, writepath, 0,
 		    "%s%s%s", _("File Name to Prepend to"), formatstr, backupstr);
 	    else if (append == 1)
-		i = statusq(1, writefile_list, answer, 0,
+		i = statusq(1, writefile_list, writepath, 0,
 		    "%s%s%s", _("File Name to Append to"), formatstr, backupstr);
 	    else
-		i = statusq(1, writefile_list, answer, 0,
+		i = statusq(1, writefile_list, writepath, 0,
 		    "%s%s%s", _("File Name to Write"), formatstr, backupstr);
 	}
 #else
 	if (append == 2)
-	    i = statusq(1, writefile_list, answer,
+	    i = statusq(1, writefile_list, writepath,
 		"%s", _("File Name to Prepend to"));
 	else if (append == 1)
-	    i = statusq(1, writefile_list, answer,
+	    i = statusq(1, writefile_list, writepath,
 		"%s", _("File Name to Append to"));
 	else
-	    i = statusq(1, writefile_list, answer,
+	    i = statusq(1, writefile_list, writepath,
 		"%s", _("File Name to Write"));
 #endif /* !NANO_SMALL */
 
